from termcolor import colored

def color_words_in_text(text, words, color='green', text_color='white'):
    color = 'on_' + color

    for word in text.split():
        if word in words:
            word = colored(word, text_color, color)
        print(word, end=' ')



from collections import Counter
import pandas as pd

def counter(counter_list):
    counter_dict = dict(Counter(counter_list))
    return counter_dict

def counter_df(counter_list):
    counter_dict = counter(counter_list)
    counter_df = pd.Series(counter_dict).to_frame('Count').reset_index()
    counter_df = counter_df.sort_values(['Count'], ascending=[False])
    return counter_df


if __name__ == '__main__':
    counter_list = [1,1,1,1,2,2,2,3,3,3]
    counter_dict = counter(counter_list)
    print(counter_dict)



import setuptools
with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
    name='chitti',
    version='0.1.5',
    author="Raja Mohan Reddy",
    author_email="rajamohanrdy@gmail.com",
    description="Python utility packages",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/raja-1996",
    packages=setuptools.find_packages(),
    classifiers=[
     "Programming Language :: Python :: 3",
     "License :: OSI Approved :: MIT License",
     "Operating System :: OS Independent",
    ],
    install_requires=[
        'colorama',
        'numpy',
        'scikit-learn',
        'matplotlib',
        'pandas'
    ]
 )


name='chitti'

from chitti.print import pprint, plen, pprint_nl
from chitti.color_text import color_words_in_text
from chitti.sklearn_utilities import plot_confusion_matrix as confusion_matrix
from chitti.list_to_dic import counter, counter_df

